summary refs log tree commit diff stats
path: root/hibp/hash.go
diff options
context:
space:
mode:
authorAndinus <andinus@nand.sh>2020-04-11 16:28:40 +0530
committerAndinus <andinus@nand.sh>2020-04-11 16:28:40 +0530
commit0ef35cae1a385f26f3d5a0ad6306b09d1fed3abd (patch)
treee757df8dd534fb9852a2a16a7a0f6e55438af8fe /hibp/hash.go
parenta9de3eef47cac76791574444380d3cd993d34e1e (diff)
downloadorion-0ef35cae1a385f26f3d5a0ad6306b09d1fed3abd.tar.gz
Return better errors in hibp package
Diffstat (limited to 'hibp/hash.go')
-rw-r--r--hibp/hash.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/hibp/hash.go b/hibp/hash.go
index 25249ed..9b8d35c 100644
--- a/hibp/hash.go
+++ b/hibp/hash.go
@@ -6,8 +6,8 @@ import (
 	"strings"
 )
 
-// GetHsh takes a string as an input & returns SHA-1 Hash
-func GetHsh(pass string) string {
+// GetSHA1Hash takes a string as an input & returns SHA-1 Hash
+func GetSHA1Hash(pass string) string {
 	alg := sha1.New()
 	alg.Write([]byte(pass))